@@ -3,9 +3,9 @@
 #include <limits.h>
 
 /*
- * $Author: Aarian.P.Aleahmad $
- * $Date: 2016/01/31 20:32:25 $
- * $Revision: 1.38 $
+ * $Author: tom $
+ * $Date: 2025/01/09 00:20:21 $
+ * $Revision: 1.40 $
  */
 
 DeclareCDKObjects (BUTTON, Button, setCdk, Int);
@@ -22,7 +22,7 @@ CDKBUTTON *newCDKButton (CDKSCREEN *cdkscreen,
 			 boolean shadow)
 {
    /* *INDENT-EQLS* */
-   CDKBUTTON *button    = 0;
+   CDKBUTTON *button    = NULL;
    int parentWidth      = getmaxx (cdkscreen->window);
    int parentHeight     = getmaxy (cdkscreen->window);
    int boxWidth         = 0;
@@ -30,8 +30,8 @@ CDKBUTTON *newCDKButton (CDKSCREEN *cdkscreen,
    int xpos             = xplace;
    int ypos             = yplace;
 
-   if ((button = newCDKObject (CDKBUTTON, &my_funcs)) == 0)
-        return (0);
+   if ((button = newCDKObject (CDKBUTTON, &my_funcs)) == NULL)
+        return (NULL);
 
    setCDKButtonBox (button, Box);
    boxHeight = 1 + 2 * BorderOf (button);
@@ -75,7 +75,7 @@ CDKBUTTON *newCDKButton (CDKSCREEN *cdkscreen,
    if (button->win == (WINDOW *)NULL)
    {
       destroyCDKObject (button);
-      return (0);
+      return (NULL);
    }
 
    keypad (button->win, TRUE);
@@ -96,17 +96,16 @@ CDKBUTTON *newCDKButton (CDKSCREEN *cdkscreen,
  */
 int activateCDKButton (CDKBUTTON *button, chtype *actions)
 {
-   chtype input = 0;
    boolean functionKey;
    int ret;
 
    drawCDKButton (button, ObjOf (button)->box);
 
-   if (actions == 0)
+   if (actions == NULL)
    {
       for (;;)
       {
-	 input = (chtype)getchCDKObject (ObjOf (button), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (button), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKButton (button, input);
@@ -191,7 +190,7 @@ boolean getCDKButtonBox (CDKBUTTON *button)
  */
 static void _setBKattrButton (CDKOBJS *object, chtype attrib)
 {
-   if (object != 0)
+   if (object != NULL)
    {
       CDKBUTTON *widget = (CDKBUTTON *)object;
 
@@ -472,7 +471,7 @@ void positionCDKButton (CDKBUTTON *button)
  */
 static void _destroyCDKButton (CDKOBJS *object)
 {
-   if (object != 0)
+   if (object != NULL)
    {
       CDKBUTTON *button = (CDKBUTTON *)object;
 
