@@ -1,4 +1,4 @@
-/* $Id: cdkalphalist.c,v 1.17 2014/01/19 02:27:01 tom Exp $ */
+/* $Id: cdkalphalist.c,v 1.19 2025/01/09 00:20:21 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -22,22 +22,21 @@ static const char *FPUsage = "-l List | -f filename [-F Field Character] [-T Tit
 int main (int argc, char **argv)
 {
    /* *INDENT-EQLS* */
-   CDKSCREEN *cdkScreen         = 0;
-   CDKALPHALIST *widget         = 0;
-   CDKBUTTONBOX *buttonWidget   = 0;
-   WINDOW *cursesWindow         = 0;
-   char *CDK_WIDGET_COLOR       = 0;
-   char *answer                 = 0;
+   CDKSCREEN *cdkScreen         = NULL;
+   CDKALPHALIST *widget         = NULL;
+   CDKBUTTONBOX *buttonWidget   = NULL;
+   char *CDK_WIDGET_COLOR       = NULL;
+   char *answer                 = NULL;
    char *buttons;
-   char *temp                   = 0;
-   chtype *holder               = 0;
+   char *temp                   = NULL;
+   chtype *holder               = NULL;
    chtype filler                = A_NORMAL | '.';
    int scrollLines              = -1;
    int buttonCount              = 0;
    int shadowHeight             = 0;
    FILE *fp                     = stderr;
-   char **scrollList            = 0;
-   char **buttonList            = 0;
+   char **scrollList            = NULL;
+   char **buttonList            = NULL;
    int j1, j2;
 
    CDK_PARAMS params;
@@ -72,9 +71,9 @@ int main (int argc, char **argv)
    title        = CDKparamString (&params, 'T');
 
    /* If the user asked for an output file, try to open it. */
-   if (outputFile != 0)
+   if (outputFile != NULL)
    {
-      if ((fp = fopen (outputFile, "w")) == 0)
+      if ((fp = fopen (outputFile, "w")) == NULL)
       {
 	 fprintf (stderr, "%s: Can not open output file %s\n", argv[0], outputFile);
 	 ExitProgram (CLI_ERROR);
@@ -82,10 +81,10 @@ int main (int argc, char **argv)
    }
 
    /* Did they provide a list of items. */
-   if (list == 0)
+   if (list == NULL)
    {
       /* Maybe they gave a filename to use to read. */
-      if (filename != 0)
+      if (filename != NULL)
       {
 	 /* Read the file in. */
 	 scrollLines = CDKreadFile (filename, &scrollList);
@@ -111,17 +110,13 @@ int main (int argc, char **argv)
       scrollLines = (int)CDKcountStrings ((CDK_CSTRING2)scrollList);
    }
 
-   /* Start curses. */
-   cursesWindow = initscr ();
-
-   /* Create the CDK screen. */
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
    initCDKColor ();
 
    /* Check if the user wants to set the background of the main screen. */
-   if ((temp = getenv ("CDK_SCREEN_COLOR")) != 0)
+   if ((temp = getenv ("CDK_SCREEN_COLOR")) != NULL)
    {
       holder = char2Chtype (temp, &j1, &j2);
       wbkgd (cdkScreen->window, holder[0]);
@@ -130,13 +125,13 @@ int main (int argc, char **argv)
    }
 
    /* Get the widget color background color. */
-   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == 0)
+   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == NULL)
    {
-      CDK_WIDGET_COLOR = 0;
+      CDK_WIDGET_COLOR = NULL;
    }
 
    /* If they set the filler character, set it now. */
-   if (tempFiller != 0)
+   if (tempFiller != NULL)
    {
       holder = char2Chtype (tempFiller, &j1, &j2);
       filler = holder[0];
@@ -152,7 +147,7 @@ int main (int argc, char **argv)
 			     boxWidget, shadowWidget);
 
    /* Make sure we could create the widget. */
-   if (widget == 0)
+   if (widget == NULL)
    {
       CDKfreeStrings (scrollList);
       destroyCDKScreen (cdkScreen);
@@ -166,7 +161,7 @@ int main (int argc, char **argv)
    }
 
    /* Split the buttons if they supplied some. */
-   if (buttons != 0)
+   if (buttons != NULL)
    {
       buttonList = CDKsplitString (buttons, '\n');
       buttonCount = (int)CDKcountStrings ((CDK_CSTRING2)buttonList);
@@ -176,7 +171,7 @@ int main (int argc, char **argv)
 				      (getbegy (widget->win)
 				       + widget->boxHeight - 1),
 				      1, widget->boxWidth - 3,
-				      0, 1, buttonCount,
+				      NULL, 1, buttonCount,
 				      (CDK_CSTRING2)buttonList, buttonCount,
 				      A_REVERSE, boxWidget, FALSE);
       CDKfreeStrings (buttonList);
@@ -216,7 +211,7 @@ int main (int argc, char **argv)
    if (shadowWidget == TRUE)
    {
       /* Determine the height of the shadow window. */
-      shadowHeight = (buttonWidget == 0 ?
+      shadowHeight = (buttonWidget == NULL ?
 		      widget->boxHeight :
 		      widget->boxHeight + buttonWidget->boxHeight - 1);
 
@@ -227,7 +222,7 @@ int main (int argc, char **argv)
 				  getbegx (widget->win) + 1);
 
       /* Make sure we could have created the shadow window. */
-      if (widget->shadowWin != 0)
+      if (widget->shadowWin != NULL)
       {
 	 widget->shadow = TRUE;
 
@@ -246,10 +241,10 @@ int main (int argc, char **argv)
    setCDKAlphalistBackgroundColor (widget, CDK_WIDGET_COLOR);
 
    /* Activate the widget. */
-   answer = copyChar (activateCDKAlphalist (widget, 0));
+   answer = copyChar (activateCDKAlphalist (widget, NULL));
 
    /* If there were buttons, get the button selected. */
-   if (buttonWidget != 0)
+   if (buttonWidget != NULL)
    {
       destroyCDKButtonbox (buttonWidget);
    }
@@ -261,7 +256,7 @@ int main (int argc, char **argv)
    endCDK ();
 
    /* Print out the answer. */
-   if (answer != 0)
+   if (answer != NULL)
    {
       fprintf (fp, "%s\n", answer);
       freeChar (answer);
