@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: label.sh,v 1.3 2005/12/27 15:53:06 tom Exp $
+# $Id: label.sh,v 1.4 2022/10/19 00:11:34 tom Exp $
 
 #
 # Description:
@@ -35,40 +35,44 @@ getDiskInfo()
       if [ "$level" -gt 4 ]; then
          command="df -kl"
       fi
-   else
-      if [ "$machine" = "AIX" ]; then
-         command="df -i"
-      fi
+   elif [ "$machine" = "AIX" ]; then
+      command="df -i"
+   elif [ "$machine" = "Linux" ]; then
+      command="df -i"
    fi
 
    #
    # Run the command.
    #
-   ${command} > ${fileName}
+   ${command} > "${fileName}"
 }
 
 #
 # Get the disk information.
 #
-getDiskInfo ${dfTmp}
+getDiskInfo "${dfTmp}"
 
 #
 # Bold the first line of the df command.
 #
-head -1 ${dfTmp} | awk '{printf "</B>%s\n", $0}' > ${top}
-tail +2 ${dfTmp} > ${bottom}
+head -1 "${dfTmp}" | awk '{printf "</B>%s\n", $0}' > "${top}"
+tail +2 "${dfTmp}" > "${bottom}"
 
 #
 # Create the message for the label widget.
 #
-echo "<C>This is the current" > ${tmp}
-echo "<C>status of your local filesystems." >> ${tmp}
-echo "<C><#HL(2)>" >> ${tmp}
-cat ${top} >> ${tmp}
-cat ${bottom} >> ${tmp}
-echo "<C><#HL(2)>" >> ${tmp}
-echo "" >> ${tmp}
-echo "<C>Hit </R>space<!R> to continue." >> ${tmp}
+cat >"${tmp}" <<EOF
+<C>This is the current
+<C>status of your local filesystems.
+<C><#HL(2)>
+EOF
+cat "${top}"    >> "${tmp}"
+cat "${bottom}" >> "${tmp}"
+cat >>"${tmp}" <<EOF
+<C><#HL(2)>
+
+<C>Hit </R>space<!R> to continue.
+EOF
 
 #
 # Create the label widget to display the information.
@@ -78,4 +82,4 @@ ${CDK_LABEL} -f "${tmp}" -p " " -c "ls" -S
 #
 # Clean up.
 #
-rm -f ${tmp} ${output} ${dfTmp} ${top} ${bottom}
+rm -f "${tmp}" "${dfTmp}" "${top}" "${bottom}"
