@@ -1,4 +1,4 @@
-/* $Id: raiseCDKObject_ex.c,v 1.11 2016/01/31 21:18:22 tom Exp $ */
+/* $Id: raiseCDKObject_ex.c,v 1.12 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -18,7 +18,6 @@ int main (int argc, char **argv)
    const char *mesg3[10];
    const char *mesg4[10];
 
-   WINDOW *cursesWin;
    CDKSCREEN *cdkscreen;
    CDKLABEL *label1, *label2, *label3, *label4, *instruct;
 
@@ -26,9 +25,7 @@ int main (int argc, char **argv)
 
    CDKparseParams (argc, argv, &params, CDK_MIN_PARAMS);
 
-   /* Set up CDK. */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    mesg1[0] = "label1 label1 label1 label1 label1 label1 label1";
    mesg1[1] = "label1 label1 label1 label1 label1 label1 label1";
