@@ -2,31 +2,31 @@
 
 /*
  * $Author: tom $
- * $Date: 2003/11/27 22:16:09 $
- * $Revision: 1.1 $
+ * $Date: 2025/01/09 00:20:21 $
+ * $Revision: 1.4 $
  */
 
 /*
  * This pops up a dialog box.
  */
-int popupDialog (CDKSCREEN *screen, char **mesg, int mesgCount, char **buttons, int buttonCount)
+int popupDialog (CDKSCREEN *screen, CDK_CSTRING2 mesg, int mesgCount, CDK_CSTRING2 buttons, int buttonCount)
 {
    /* Declare local variables. */
-   CDKDIALOG *popup	= 0;
+   CDKDIALOG *popup	= NULL;
    int choice;
 
    /* Create the dialog box. */
    popup = newCDKDialog (screen, CENTER, CENTER,
-				mesg, mesgCount,
-				buttons, buttonCount,
-				A_REVERSE, TRUE,
-				TRUE, FALSE);
+			 mesg, mesgCount,
+			 buttons, buttonCount,
+			 A_REVERSE, TRUE,
+			 TRUE, FALSE);
 
    /* Activate the dialog box */
    drawCDKDialog (popup, TRUE);
 
    /* Get the choice. */
-   choice = activateCDKDialog (popup, 0);
+   choice = activateCDKDialog (popup, NULL);
 
    /* Destroy the dialog box. */
    destroyCDKDialog (popup);
